@@ -8,6 +8,7 @@ import (
 	"strings"
 
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/internal/choice"
 	"github.com/influxdata/telegraf/plugins/aggregators"
 	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/plugins/outputs"
@@ -17,12 +18,10 @@ import (
 
 var (
 	// Default sections
-	sectionDefaults = []string{"global_tags", "agent", "secretstores",
-		"outputs", "processors", "aggregators", "inputs"}
+	sectionDefaults = []string{"global_tags", "agent", "secretstores", "outputs", "processors", "aggregators", "inputs"}
 
 	// Default input plugins
-	inputDefaults = []string{"cpu", "mem", "swap", "system", "kernel",
-		"processes", "disk", "diskio"}
+	inputDefaults = []string{"cpu", "mem", "swap", "system", "kernel", "processes", "disk", "diskio"}
 
 	// Default output plugins
 	outputDefaults = []string{}
@@ -101,25 +100,15 @@ var serviceInputHeader = `
 
 `
 
-func sliceContains(name string, list []string) bool {
-	for _, b := range list {
-		if b == name {
-			return true
-		}
-	}
-	return false
-}
-
 // printSampleConfig prints the sample config
-func printSampleConfig(
-	outputBuffer io.Writer,
-	sectionFilters []string,
-	inputFilters []string,
-	outputFilters []string,
-	aggregatorFilters []string,
-	processorFilters []string,
-	secretstoreFilters []string,
-) {
+func printSampleConfig(outputBuffer io.Writer, filters Filters) {
+	sectionFilters := filters.section
+	inputFilters := filters.input
+	outputFilters := filters.output
+	aggregatorFilters := filters.aggregator
+	processorFilters := filters.processor
+	secretstoreFilters := filters.secretstore
+
 	// print headers
 	outputBuffer.Write([]byte(header))
 
@@ -129,7 +118,7 @@ func printSampleConfig(
 	printFilteredGlobalSections(sectionFilters, outputBuffer)
 
 	// print secretstore plugins
-	if sliceContains("secretstores", sectionFilters) {
+	if choice.Contains("secretstores", sectionFilters) {
 		if len(secretstoreFilters) != 0 {
 			if len(secretstoreFilters) >= 3 && secretstoreFilters[1] != "none" {
 				fmt.Print(secretstoreHeader)
@@ -147,7 +136,7 @@ func printSampleConfig(
 	}
 
 	// print output plugins
-	if sliceContains("outputs", sectionFilters) {
+	if choice.Contains("outputs", sectionFilters) {
 		if len(outputFilters) != 0 {
 			if len(outputFilters) >= 3 && outputFilters[1] != "none" {
 				outputBuffer.Write([]byte(outputHeader))
@@ -159,7 +148,7 @@ func printSampleConfig(
 			// Print non-default outputs, commented
 			var pnames []string
 			for pname := range outputs.Outputs {
-				if !sliceContains(pname, outputDefaults) {
+				if !choice.Contains(pname, outputDefaults) {
 					pnames = append(pnames, pname)
 				}
 			}
@@ -168,7 +157,7 @@ func printSampleConfig(
 	}
 
 	// print processor plugins
-	if sliceContains("processors", sectionFilters) {
+	if choice.Contains("processors", sectionFilters) {
 		if len(processorFilters) != 0 {
 			if len(processorFilters) >= 3 && processorFilters[1] != "none" {
 				outputBuffer.Write([]byte(processorHeader))
@@ -185,7 +174,7 @@ func printSampleConfig(
 	}
 
 	// print aggregator plugins
-	if sliceContains("aggregators", sectionFilters) {
+	if choice.Contains("aggregators", sectionFilters) {
 		if len(aggregatorFilters) != 0 {
 			if len(aggregatorFilters) >= 3 && aggregatorFilters[1] != "none" {
 				outputBuffer.Write([]byte(aggregatorHeader))
@@ -202,7 +191,7 @@ func printSampleConfig(
 	}
 
 	// print input plugins
-	if sliceContains("inputs", sectionFilters) {
+	if choice.Contains("inputs", sectionFilters) {
 		if len(inputFilters) != 0 {
 			if len(inputFilters) >= 3 && inputFilters[1] != "none" {
 				outputBuffer.Write([]byte(inputHeader))
@@ -214,7 +203,7 @@ func printSampleConfig(
 			// Print non-default inputs, commented
 			var pnames []string
 			for pname := range inputs.Inputs {
-				if !sliceContains(pname, inputDefaults) {
+				if !choice.Contains(pname, inputDefaults) {
 					pnames = append(pnames, pname)
 				}
 			}
@@ -227,7 +216,7 @@ func printFilteredProcessors(processorFilters []string, commented bool, outputBu
 	// Filter processors
 	var pnames []string
 	for pname := range processors.Processors {
-		if sliceContains(pname, processorFilters) {
+		if choice.Contains(pname, processorFilters) {
 			pnames = append(pnames, pname)
 		}
 	}
@@ -245,7 +234,7 @@ func printFilteredAggregators(aggregatorFilters []string, commented bool, output
 	// Filter outputs
 	var anames []string
 	for aname := range aggregators.Aggregators {
-		if sliceContains(aname, aggregatorFilters) {
+		if choice.Contains(aname, aggregatorFilters) {
 			anames = append(anames, aname)
 		}
 	}
@@ -263,7 +252,7 @@ func printFilteredInputs(inputFilters []string, commented bool, outputBuffer io.
 	// Filter inputs
 	var pnames []string
 	for pname := range inputs.Inputs {
-		if sliceContains(pname, inputFilters) {
+		if choice.Contains(pname, inputFilters) {
 			pnames = append(pnames, pname)
 		}
 	}
@@ -311,7 +300,7 @@ func printFilteredOutputs(outputFilters []string, commented bool, outputBuffer i
 	var influxdbV2 string
 
 	for oname := range outputs.Outputs {
-		if sliceContains(oname, outputFilters) {
+		if choice.Contains(oname, outputFilters) {
 			// Make influxdb_v2 the exception and have it be first in the list
 			// Store it and add it later
 			if oname == "influxdb_v2" {
@@ -340,7 +329,7 @@ func printFilteredSecretstores(secretstoreFilters []string, commented bool, outp
 	// Filter secretstores
 	var snames []string
 	for sname := range secretstores.SecretStores {
-		if sliceContains(sname, secretstoreFilters) {
+		if choice.Contains(sname, secretstoreFilters) {
 			snames = append(snames, sname)
 		}
 	}
@@ -355,11 +344,11 @@ func printFilteredSecretstores(secretstoreFilters []string, commented bool, outp
 }
 
 func printFilteredGlobalSections(sectionFilters []string, outputBuffer io.Writer) {
-	if sliceContains("global_tags", sectionFilters) {
+	if choice.Contains("global_tags", sectionFilters) {
 		outputBuffer.Write([]byte(globalTagsConfig))
 	}
 
-	if sliceContains("agent", sectionFilters) {
+	if choice.Contains("agent", sectionFilters) {
 		outputBuffer.Write([]byte(agentConfig))
 	}
 }
