@@ -4,6 +4,7 @@ import (
 	"bufio"
 	"compress/gzip"
 	"context"
+	cryptoRand "crypto/rand"
 	"errors"
 	"fmt"
 	"io"
@@ -24,8 +25,8 @@ import (
 const alphanum string = "0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz"
 
 var (
-	ErrTimeout          = errors.New("command timed out")
-	ErrorNotImplemented = errors.New("not implemented yet")
+	ErrTimeout        = errors.New("command timed out")
+	ErrNotImplemented = errors.New("not implemented yet")
 )
 
 // Set via LDFLAGS -X
@@ -87,13 +88,16 @@ func ReadLines(filename string) ([]string, error) {
 }
 
 // RandomString returns a random string of alphanumeric characters
-func RandomString(n int) string {
+func RandomString(n int) (string, error) {
 	var bytes = make([]byte, n)
-	rand.Read(bytes) //nolint:revive // from math/rand/rand.go: "It always returns len(p) and a nil error."
+	_, err := cryptoRand.Read(bytes)
+	if err != nil {
+		return "", err
+	}
 	for i, b := range bytes {
 		bytes[i] = alphanum[b%byte(len(alphanum))]
 	}
-	return string(bytes)
+	return string(bytes), nil
 }
 
 // SnakeCase converts the given string to snake case following the Golang format:
@@ -194,30 +198,39 @@ func (r *ReadWaitCloser) Close() error {
 	return err
 }
 
-// CompressWithGzip takes an io.Reader as input and pipes
-// it through a gzip.Writer returning an io.Reader containing
-// the gzipped data.
-// An error is returned if passing data to the gzip.Writer fails
-func CompressWithGzip(data io.Reader) (io.ReadCloser, error) {
+// CompressWithGzip takes an io.Reader as input and pipes it through a
+// gzip.Writer returning an io.Reader containing the gzipped data.
+// Errors occurring during compression are returned to the instance reading
+// from the returned reader via through the corresponding read call
+// (e.g. io.Copy or io.ReadAll).
+func CompressWithGzip(data io.Reader) io.ReadCloser {
 	pipeReader, pipeWriter := io.Pipe()
 	gzipWriter := gzip.NewWriter(pipeWriter)
 
-	rc := &ReadWaitCloser{
-		pipeReader: pipeReader,
-	}
-
-	rc.wg.Add(1)
-	var err error
+	// Start copying from the uncompressed reader to the output reader
+	// in the background until the input reader is closed (or errors out).
 	go func() {
-		_, err = io.Copy(gzipWriter, data)
-		gzipWriter.Close()
-		// subsequent reads from the read half of the pipe will
-		// return no bytes and the error err, or EOF if err is nil.
-		pipeWriter.CloseWithError(err)
-		rc.wg.Done()
+		// This copy will block until "data" reached EOF or an error occurs
+		_, err := io.Copy(gzipWriter, data)
+
+		// Close the compression writer and make sure we do not overwrite
+		// the copy error if any.
+		gzipErr := gzipWriter.Close()
+		if err == nil {
+			err = gzipErr
+		}
+
+		// Subsequent reads from the output reader (connected to "pipeWriter"
+		// via pipe) will return the copy (or closing) error if any to the
+		// instance reading from the reader returned by the CompressWithGzip
+		// function. If "err" is nil, the below function will correctly report
+		// io.EOF.
+		_ = pipeWriter.CloseWithError(err)
 	}()
 
-	return pipeReader, err
+	// Return a reader which then can be read by the caller to collect the
+	// compressed stream.
+	return pipeReader
 }
 
 // ParseTimestamp parses a Time according to the standard Telegraf options.
