@@ -123,8 +123,8 @@ func (q *Quantile) Init() error {
 	}
 
 	duplicates := make(map[float64]bool)
-	q.suffixes = make([]string, len(q.Quantiles))
-	for i, qtl := range q.Quantiles {
+	q.suffixes = make([]string, 0, len(q.Quantiles))
+	for _, qtl := range q.Quantiles {
 		if qtl < 0.0 || qtl > 1.0 {
 			return fmt.Errorf("quantile %v out of range", qtl)
 		}
@@ -132,7 +132,7 @@ func (q *Quantile) Init() error {
 			return fmt.Errorf("duplicate quantile %v", qtl)
 		}
 		duplicates[qtl] = true
-		q.suffixes[i] = fmt.Sprintf("_%03d", int(qtl*100.0))
+		q.suffixes = append(q.suffixes, fmt.Sprintf("_%03d", int(qtl*100.0)))
 	}
 
 	q.Reset()
