@@ -19,8 +19,6 @@ import (
 	jsonParser "github.com/influxdata/telegraf/plugins/parsers/json"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -266,11 +264,11 @@ func (logstash *Logstash) gatherPluginsStats(
 			accumulator.AddFields("logstash_plugins", failuresFields, pluginTags)
 		}
 		/*
-			The elasticsearch output produces additional stats around
-			bulk requests and document writes (that are elasticsearch specific).
-			Collect those here
+			The elasticsearch & opensearch output produces additional stats
+			around bulk requests and document writes (that are elasticsearch
+			and opensearch specific). Collect those below:
 		*/
-		if pluginType == "output" && plugin.Name == "elasticsearch" {
+		if pluginType == "output" && (plugin.Name == "elasticsearch" || plugin.Name == "opensearch") {
 			/*
 				The "bulk_requests" section has details about batch writes
 				into Elasticsearch
