@@ -12,9 +12,7 @@ import (
 	"github.com/gosnmp/gosnmp"
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal/snmp"
-	"github.com/influxdata/telegraf/plugins/inputs"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/influxdata/toml"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 )
@@ -59,6 +57,9 @@ func (tsc *testSNMPConnection) Walk(oid string, wf gosnmp.WalkFunc) error {
 	}
 	return nil
 }
+func (tsc *testSNMPConnection) Reconnect() error {
+	return nil
+}
 
 var tsc = &testSNMPConnection{
 	host: "tsc",
@@ -93,27 +94,6 @@ var tsc = &testSNMPConnection{
 	},
 }
 
-func TestSampleConfig(t *testing.T) {
-	conf := inputs.Inputs["snmp"]()
-	err := toml.Unmarshal([]byte(conf.SampleConfig()), conf)
-	require.NoError(t, err)
-
-	expected := &Snmp{
-		Agents:       []string{"udp://127.0.0.1:161"},
-		AgentHostTag: "",
-		ClientConfig: snmp.ClientConfig{
-			Timeout:        config.Duration(5 * time.Second),
-			Version:        2,
-			Path:           []string{"/usr/share/snmp/mibs"},
-			Community:      "public",
-			MaxRepetitions: 10,
-			Retries:        3,
-		},
-		Name: "snmp",
-	}
-	require.Equal(t, expected, conf)
-}
-
 func TestFieldInit(t *testing.T) {
 	translations := []struct {
 		inputOid           string
@@ -307,38 +287,26 @@ func TestGetSNMPConnection_v2(t *testing.T) {
 }
 
 func TestGetSNMPConnectionTCP(t *testing.T) {
-	var wg sync.WaitGroup
-	wg.Add(1)
-	go stubTCPServer(&wg)
-	wg.Wait()
+	tcpAddr, err := net.ResolveTCPAddr("tcp", "127.0.0.1:0")
+	require.NoError(t, err)
+
+	tcpServer, err := net.ListenTCP("tcp", tcpAddr)
+	require.NoError(t, err)
+	defer tcpServer.Close()
 
 	s := &Snmp{
-		Agents: []string{"tcp://127.0.0.1:56789"},
+		Agents: []string{fmt.Sprintf("tcp://%s", tcpServer.Addr())},
 		ClientConfig: snmp.ClientConfig{
 			Translator: "netsnmp",
 		},
 	}
-	err := s.Init()
-	require.NoError(t, err)
+	require.NoError(t, s.Init())
 
-	wg.Add(1)
 	gsc, err := s.getConnection(0)
 	require.NoError(t, err)
 	gs := gsc.(snmp.GosnmpWrapper)
 	assert.Equal(t, "127.0.0.1", gs.Target)
-	assert.EqualValues(t, 56789, gs.Port)
 	assert.Equal(t, "tcp", gs.Transport)
-	wg.Wait()
-}
-
-func stubTCPServer(wg *sync.WaitGroup) {
-	defer wg.Done()
-	tcpAddr, _ := net.ResolveTCPAddr("tcp", "127.0.0.1:56789")
-	tcpServer, _ := net.ListenTCP("tcp", tcpAddr)
-	defer tcpServer.Close()
-	wg.Done()
-	conn, _ := tcpServer.AcceptTCP()
-	defer conn.Close()
 }
 
 func TestGetSNMPConnection_v3(t *testing.T) {
@@ -528,9 +496,8 @@ func TestGetSNMPConnection_caching(t *testing.T) {
 }
 
 func TestGosnmpWrapper_walk_retry(t *testing.T) {
-	if testing.Short() {
-		t.Skip("Skipping test due to random failures.")
-	}
+	t.Skip("Skipping test due to random failures.")
+
 	srvr, err := net.ListenUDP("udp4", &net.UDPAddr{})
 	require.NoError(t, err)
 	defer srvr.Close()
@@ -916,7 +883,7 @@ func TestFieldConvert(t *testing.T) {
 	}
 
 	for _, tc := range testTable {
-		act, err := fieldConvert(tc.conv, tc.input)
+		act, err := fieldConvert(NewNetsnmpTranslator(), tc.conv, gosnmp.SnmpPDU{Value: tc.input})
 		if !assert.NoError(t, err, "input=%T(%v) conv=%s expected=%T(%v)", tc.input, tc.input, tc.conv, tc.expected, tc.expected) {
 			continue
 		}
