@@ -97,9 +97,7 @@ func (s *Syslog) Start(acc telegraf.Accumulator) error {
 	}
 
 	if scheme == "unix" || scheme == "unixpacket" || scheme == "unixgram" {
-		// Accept success and failure in case the file does not exist
-		//nolint:errcheck,revive
-		os.Remove(s.Address)
+		os.Remove(s.Address) //nolint:revive // Accept success and failure in case the file does not exist
 	}
 
 	if s.isStream {
@@ -141,9 +139,7 @@ func (s *Syslog) Stop() {
 	defer s.mu.Unlock()
 
 	if s.Closer != nil {
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		s.Close()
+		s.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 	}
 	s.wg.Wait()
 }
@@ -209,6 +205,9 @@ func (s *Syslog) listenPacket(acc telegraf.Accumulator) {
 		if err != nil {
 			acc.AddError(err)
 		}
+		if err == nil && message == nil {
+			acc.AddError(fmt.Errorf("unable to parse message: %s", string(b[:n])))
+		}
 	}
 }
 
@@ -266,9 +265,7 @@ func (s *Syslog) removeConnection(c net.Conn) {
 func (s *Syslog) handle(conn net.Conn, acc telegraf.Accumulator) {
 	defer func() {
 		s.removeConnection(conn)
-		// Ignore the returned error as we cannot do anything about it anyway
-		//nolint:errcheck,revive
-		conn.Close()
+		conn.Close() //nolint:revive // Ignore the returned error as we cannot do anything about it anyway
 	}()
 
 	var p syslog.Parser
@@ -419,9 +416,7 @@ type unixCloser struct {
 
 func (uc unixCloser) Close() error {
 	err := uc.closer.Close()
-	// Accept success and failure in case the file does not exist
-	//nolint:errcheck,revive
-	os.Remove(uc.path)
+	os.Remove(uc.path) //nolint:revive // Accept success and failure in case the file does not exist
 	return err
 }
 
