@@ -9,12 +9,14 @@ import (
 	"crypto/x509"
 	_ "embed"
 	"encoding/pem"
+	"errors"
 	"fmt"
 	"net"
 	"net/smtp"
 	"net/url"
 	"os"
 	"path/filepath"
+	"regexp"
 	"strings"
 	"time"
 
@@ -24,34 +26,139 @@ import (
 	"github.com/influxdata/telegraf/config"
 	"github.com/influxdata/telegraf/internal/globpath"
 	"github.com/influxdata/telegraf/plugins/common/proxy"
-	_tls "github.com/influxdata/telegraf/plugins/common/tls"
+	commontls "github.com/influxdata/telegraf/plugins/common/tls"
 	"github.com/influxdata/telegraf/plugins/inputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
+// Regexp for handling file URIs containing a drive letter and leading slash
+var reDriveLetter = regexp.MustCompile(`^/([a-zA-Z]:/)`)
+
 // X509Cert holds the configuration of the plugin.
 type X509Cert struct {
 	Sources          []string        `toml:"sources"`
 	Timeout          config.Duration `toml:"timeout"`
 	ServerName       string          `toml:"server_name"`
 	ExcludeRootCerts bool            `toml:"exclude_root_certs"`
-	tlsCfg           *tls.Config
-	_tls.ClientConfig
+	Log              telegraf.Logger `toml:"-"`
+	commontls.ClientConfig
 	proxy.TCPProxy
+
+	tlsCfg    *tls.Config
 	locations []*url.URL
 	globpaths []*globpath.GlobPath
-	Log       telegraf.Logger
+}
+
+func (*X509Cert) SampleConfig() string {
+	return sampleConfig
+}
+
+func (c *X509Cert) Init() error {
+	// Check if we do have at least one source
+	if len(c.Sources) == 0 {
+		return errors.New("no source configured")
+	}
+
+	// Check the server name and transfer it if necessary
+	if c.ClientConfig.ServerName != "" && c.ServerName != "" {
+		return fmt.Errorf("both server_name (%q) and tls_server_name (%q) are set, but they are mutually exclusive", c.ServerName, c.ClientConfig.ServerName)
+	} else if c.ServerName != "" {
+		// Store the user-provided server-name in the TLS configuration
+		c.ClientConfig.ServerName = c.ServerName
+	}
+
+	// Normalize the sources, handle files and file-globbing
+	if err := c.sourcesToURLs(); err != nil {
+		return err
+	}
+
+	// Create the TLS configuration
+	tlsCfg, err := c.ClientConfig.TLSConfig()
+	if err != nil {
+		return err
+	}
+	if tlsCfg == nil {
+		tlsCfg = &tls.Config{}
+	}
+	c.tlsCfg = tlsCfg
+
+	return nil
+}
+
+// Gather adds metrics into the accumulator.
+func (c *X509Cert) Gather(acc telegraf.Accumulator) error {
+	now := time.Now()
+
+	collectedUrls := append(c.locations, c.collectCertURLs()...)
+	for _, location := range collectedUrls {
+		certs, err := c.getCert(location, time.Duration(c.Timeout))
+		if err != nil {
+			acc.AddError(fmt.Errorf("cannot get SSL cert '%s': %s", location, err.Error()))
+		}
+
+		dnsName := c.serverName(location)
+		for i, cert := range certs {
+			fields := getFields(cert, now)
+			tags := getTags(cert, location.String())
+
+			// The first certificate is the leaf/end-entity certificate which
+			// needs DNS name validation against the URL hostname.
+			opts := x509.VerifyOptions{
+				Intermediates: x509.NewCertPool(),
+				KeyUsages:     []x509.ExtKeyUsage{x509.ExtKeyUsageAny},
+				Roots:         c.tlsCfg.RootCAs,
+				DNSName:       dnsName,
+			}
+			// Reset DNS name to only use it for the leaf node
+			dnsName = ""
+
+			// Add all returned certs to the pool if intermediates except for
+			// the leaf node and ourself
+			for j, c := range certs[1:] {
+				if i+1 != j {
+					opts.Intermediates.AddCert(c)
+				}
+			}
+
+			if _, err := cert.Verify(opts); err == nil {
+				tags["verification"] = "valid"
+				fields["verification_code"] = 0
+			} else {
+				c.Log.Debugf("Invalid certificate at index %2d!", i)
+				c.Log.Debugf("  cert DNS names:    %v", cert.DNSNames)
+				c.Log.Debugf("  cert IP addresses: %v", cert.IPAddresses)
+				c.Log.Debugf("  cert subject:      %v", cert.Subject)
+				c.Log.Debugf("  cert issuer:       %v", cert.Issuer)
+				c.Log.Debugf("  opts.DNSName:      %v", opts.DNSName)
+				c.Log.Debugf("  verify options:    %v", opts)
+				c.Log.Debugf("  verify error:      %v", err)
+				c.Log.Debugf("  location:          %v", location)
+				c.Log.Debugf("  tlsCfg.ServerName: %v", c.tlsCfg.ServerName)
+				c.Log.Debugf("  ServerName:        %v", c.ServerName)
+				tags["verification"] = "invalid"
+				fields["verification_code"] = 1
+				fields["verification_error"] = err.Error()
+			}
+
+			acc.AddFields("x509_cert", fields, tags)
+			if c.ExcludeRootCerts {
+				break
+			}
+		}
+	}
+
+	return nil
 }
 
 func (c *X509Cert) sourcesToURLs() error {
 	for _, source := range c.Sources {
-		if strings.HasPrefix(source, "file://") ||
-			strings.HasPrefix(source, "/") {
+		if strings.HasPrefix(source, "file://") || strings.HasPrefix(source, "/") {
 			source = filepath.ToSlash(strings.TrimPrefix(source, "file://"))
+			// Removing leading slash in Windows path containing a drive-letter
+			// like "file:///C:/Windows/..."
+			source = reDriveLetter.ReplaceAllString(source, "$1")
 			g, err := globpath.Compile(source)
 			if err != nil {
 				return fmt.Errorf("could not compile glob %v: %v", source, err)
@@ -72,17 +179,11 @@ func (c *X509Cert) sourcesToURLs() error {
 	return nil
 }
 
-func (c *X509Cert) serverName(u *url.URL) (string, error) {
+func (c *X509Cert) serverName(u *url.URL) string {
 	if c.tlsCfg.ServerName != "" {
-		if c.ServerName != "" {
-			return "", fmt.Errorf("both server_name (%q) and tls_server_name (%q) are set, but they are mutually exclusive", c.ServerName, c.tlsCfg.ServerName)
-		}
-		return c.tlsCfg.ServerName, nil
+		return c.tlsCfg.ServerName
 	}
-	if c.ServerName != "" {
-		return c.ServerName, nil
-	}
-	return u.Hostname(), nil
+	return u.Hostname()
 }
 
 func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certificate, error) {
@@ -95,16 +196,11 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 		}
 		defer ipConn.Close()
 
-		serverName, err := c.serverName(u)
-		if err != nil {
-			return nil, err
-		}
-
 		dtlsCfg := &dtls.Config{
 			InsecureSkipVerify: true,
 			Certificates:       c.tlsCfg.Certificates,
 			RootCAs:            c.tlsCfg.RootCAs,
-			ServerName:         serverName,
+			ServerName:         c.serverName(u),
 		}
 		conn, err := dtls.Client(ipConn, dtlsCfg)
 		if err != nil {
@@ -128,26 +224,23 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 		return certs, nil
 	case "https":
 		protocol = "tcp"
+		if u.Port() == "" {
+			u.Host += ":443"
+		}
 		fallthrough
 	case "tcp", "tcp4", "tcp6":
 		dialer, err := c.Proxy()
 		if err != nil {
 			return nil, err
 		}
-
 		ipConn, err := dialer.DialTimeout(protocol, u.Host, timeout)
 		if err != nil {
 			return nil, err
 		}
 		defer ipConn.Close()
 
-		serverName, err := c.serverName(u)
-		if err != nil {
-			return nil, err
-		}
-
 		downloadTLSCfg := c.tlsCfg.Clone()
-		downloadTLSCfg.ServerName = serverName
+		downloadTLSCfg.ServerName = c.serverName(u)
 		downloadTLSCfg.InsecureSkipVerify = true
 
 		conn := tls.Client(ipConn, downloadTLSCfg)
@@ -193,13 +286,8 @@ func (c *X509Cert) getCert(u *url.URL, timeout time.Duration) ([]*x509.Certifica
 		}
 		defer ipConn.Close()
 
-		serverName, err := c.serverName(u)
-		if err != nil {
-			return nil, err
-		}
-
 		downloadTLSCfg := c.tlsCfg.Clone()
-		downloadTLSCfg.ServerName = serverName
+		downloadTLSCfg.ServerName = c.serverName(u)
 		downloadTLSCfg.InsecureSkipVerify = true
 
 		smtpConn, err := smtp.NewClient(ipConn, u.Host)
@@ -296,132 +384,28 @@ func getTags(cert *x509.Certificate, location string) map[string]string {
 	return tags
 }
 
-func (c *X509Cert) collectCertURLs() ([]*url.URL, error) {
+func (c *X509Cert) collectCertURLs() []*url.URL {
 	var urls []*url.URL
 
 	for _, path := range c.globpaths {
 		files := path.Match()
 		if len(files) <= 0 {
-			c.Log.Errorf("could not find file: %v", path)
+			c.Log.Errorf("could not find file: %v", path.GetRoots())
 			continue
 		}
 		for _, file := range files {
-			file = "file://" + file
-			u, err := url.Parse(file)
-			if err != nil {
-				return urls, fmt.Errorf("failed to parse cert location - %s", err.Error())
-			}
-			urls = append(urls, u)
+			fn := filepath.ToSlash(file)
+			urls = append(urls, &url.URL{Scheme: "file", Path: fn})
 		}
 	}
 
-	return urls, nil
-}
-
-func (*X509Cert) SampleConfig() string {
-	return sampleConfig
-}
-
-// Gather adds metrics into the accumulator.
-func (c *X509Cert) Gather(acc telegraf.Accumulator) error {
-	now := time.Now()
-	collectedUrls, err := c.collectCertURLs()
-	if err != nil {
-		acc.AddError(fmt.Errorf("cannot get file: %s", err.Error()))
-	}
-
-	for _, location := range append(c.locations, collectedUrls...) {
-		certs, err := c.getCert(location, time.Duration(c.Timeout))
-		if err != nil {
-			acc.AddError(fmt.Errorf("cannot get SSL cert '%s': %s", location, err.Error()))
-		}
-
-		for i, cert := range certs {
-			fields := getFields(cert, now)
-			tags := getTags(cert, location.String())
-
-			// The first certificate is the leaf/end-entity certificate which needs DNS
-			// name validation against the URL hostname.
-			opts := x509.VerifyOptions{
-				Intermediates: x509.NewCertPool(),
-				KeyUsages:     []x509.ExtKeyUsage{x509.ExtKeyUsageAny},
-			}
-			if i == 0 {
-				opts.DNSName, err = c.serverName(location)
-				if err != nil {
-					return err
-				}
-				for j, cert := range certs {
-					if j != 0 {
-						opts.Intermediates.AddCert(cert)
-					}
-				}
-			}
-			if c.tlsCfg.RootCAs != nil {
-				opts.Roots = c.tlsCfg.RootCAs
-			}
-
-			_, err = cert.Verify(opts)
-			if err == nil {
-				tags["verification"] = "valid"
-				fields["verification_code"] = 0
-			} else {
-				c.Log.Debugf("Invalid certificate at index %2d!", i)
-				c.Log.Debugf("  cert DNS names:    %v", cert.DNSNames)
-				c.Log.Debugf("  cert IP addresses: %v", cert.IPAddresses)
-				c.Log.Debugf("  opts.DNSName:      %v", opts.DNSName)
-				c.Log.Debugf("  verify options:    %v", opts)
-				c.Log.Debugf("  verify error:      %v", err)
-				c.Log.Debugf("  location:          %v", location)
-				c.Log.Debugf("  tlsCfg.ServerName: %v", c.tlsCfg.ServerName)
-				c.Log.Debugf("  ServerName:        %v", c.ServerName)
-				tags["verification"] = "invalid"
-				fields["verification_code"] = 1
-				fields["verification_error"] = err.Error()
-			}
-
-			acc.AddFields("x509_cert", fields, tags)
-			if c.ExcludeRootCerts {
-				break
-			}
-		}
-	}
-
-	return nil
-}
-
-func (c *X509Cert) Init() error {
-	err := c.sourcesToURLs()
-	if err != nil {
-		return err
-	}
-
-	tlsCfg, err := c.ClientConfig.TLSConfig()
-	if err != nil {
-		return err
-	}
-	if tlsCfg == nil {
-		tlsCfg = &tls.Config{}
-	}
-
-	if tlsCfg.ServerName != "" && c.ServerName == "" {
-		// Save SNI from tlsCfg.ServerName to c.ServerName and reset tlsCfg.ServerName.
-		// We need to reset c.tlsCfg.ServerName for each certificate when there's
-		// no explicit SNI (c.tlsCfg.ServerName or c.ServerName) otherwise we'll always (re)use
-		// first uri HostName for all certs (see issue 8914)
-		c.ServerName = tlsCfg.ServerName
-		tlsCfg.ServerName = ""
-	}
-	c.tlsCfg = tlsCfg
-
-	return nil
+	return urls
 }
 
 func init() {
 	inputs.Add("x509_cert", func() telegraf.Input {
 		return &X509Cert{
-			Sources: []string{},
-			Timeout: config.Duration(5 * time.Second), // set default timeout to 5s
+			Timeout: config.Duration(5 * time.Second),
 		}
 	})
 }
