@@ -6,6 +6,7 @@ import (
 	_ "embed"
 	"encoding/json"
 	"fmt"
+	"io"
 	"math"
 	"net/http"
 	"net/url"
@@ -19,8 +20,6 @@ import (
 	"github.com/influxdata/telegraf/plugins/outputs"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
-//
 //go:embed sample.conf
 var sampleConfig string
 
@@ -170,7 +169,9 @@ func (d *Datadog) Write(metrics []telegraf.Metric) error {
 	defer resp.Body.Close()
 
 	if resp.StatusCode < 200 || resp.StatusCode > 209 {
-		return fmt.Errorf("received bad status code, %d", resp.StatusCode)
+		// err can be ignored
+		body, _ := io.ReadAll(resp.Body)
+		return fmt.Errorf("received bad status code, %d: %s", resp.StatusCode, string(body))
 	}
 
 	return nil
@@ -200,11 +201,9 @@ func buildMetrics(m telegraf.Metric) (map[string]Point, error) {
 }
 
 func buildTags(tagList []*telegraf.Tag) []string {
-	tags := make([]string, len(tagList))
-	index := 0
+	tags := make([]string, 0, len(tagList))
 	for _, tag := range tagList {
-		tags[index] = fmt.Sprintf("%s:%s", tag.Key, tag.Value)
-		index++
+		tags = append(tags, fmt.Sprintf("%s:%s", tag.Key, tag.Value))
 	}
 	return tags
 }
