@@ -1,4 +1,3 @@
-// nolint
 package influxdb_test
 
 import (
@@ -16,12 +15,13 @@ import (
 	"testing"
 	"time"
 
+	"github.com/stretchr/testify/require"
+
 	"github.com/influxdata/telegraf"
 	"github.com/influxdata/telegraf/internal"
 	"github.com/influxdata/telegraf/metric"
 	"github.com/influxdata/telegraf/plugins/outputs/influxdb"
 	"github.com/influxdata/telegraf/testutil"
-	"github.com/stretchr/testify/require"
 )
 
 func getHTTPURL() *url.URL {
@@ -33,28 +33,28 @@ func getHTTPURL() *url.URL {
 }
 
 func TestHTTP_EmptyConfig(t *testing.T) {
-	config := influxdb.HTTPConfig{}
-	_, err := influxdb.NewHTTPClient(config)
+	cfg := influxdb.HTTPConfig{}
+	_, err := influxdb.NewHTTPClient(cfg)
 	require.Error(t, err)
 	require.Contains(t, err.Error(), influxdb.ErrMissingURL.Error())
 }
 
 func TestHTTP_MinimalConfig(t *testing.T) {
-	config := influxdb.HTTPConfig{
+	cfg := influxdb.HTTPConfig{
 		URL: getHTTPURL(),
 	}
-	_, err := influxdb.NewHTTPClient(config)
+	_, err := influxdb.NewHTTPClient(cfg)
 	require.NoError(t, err)
 }
 
 func TestHTTP_UnsupportedScheme(t *testing.T) {
-	config := influxdb.HTTPConfig{
+	cfg := influxdb.HTTPConfig{
 		URL: &url.URL{
 			Scheme: "foo",
 			Host:   "localhost",
 		},
 	}
-	_, err := influxdb.NewHTTPClient(config)
+	_, err := influxdb.NewHTTPClient(cfg)
 	require.Error(t, err)
 }
 
@@ -83,7 +83,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				require.Equal(t, `CREATE DATABASE "xyzzy"`, r.FormValue("q"))
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -101,7 +102,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 				require.Equal(t, "guy", username)
 				require.Equal(t, "smiley", password)
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -119,7 +121,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 				require.Equal(t, r.Header.Get("A"), "B")
 				require.Equal(t, r.Header.Get("C"), "D")
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -136,7 +139,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 				require.Equal(t, r.Header.Get("A"), "B")
 				require.Equal(t, r.Header.Get("C"), "D")
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -147,7 +151,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				require.Equal(t, `CREATE DATABASE "telegraf"`, r.FormValue("q"))
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -159,7 +164,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				require.Equal(t, `CREATE DATABASE "a \" b"`, r.FormValue("q"))
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 		{
@@ -171,7 +177,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				// Yes, 200 OK is the correct response...
 				w.WriteHeader(http.StatusOK)
-				w.Write([]byte(`{"results": [{"error": "invalid name", "statement_id": 0}]}`))
+				_, err = w.Write([]byte(`{"results": [{"error": "invalid name", "statement_id": 0}]}`))
+				require.NoError(t, err)
 			},
 			errFunc: func(t *testing.T, err error) {
 				expected := &influxdb.APIError{
@@ -219,7 +226,8 @@ func TestHTTP_CreateDatabase(t *testing.T) {
 			},
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusBadRequest)
-				w.Write([]byte(`invalid response`))
+				_, err = w.Write([]byte(`invalid response`))
+				require.NoError(t, err)
 			},
 			errFunc: func(t *testing.T, err error) {
 				expected := &influxdb.APIError{
@@ -393,7 +401,8 @@ func TestHTTP_Write(t *testing.T) {
 			},
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusBadRequest)
-				w.Write([]byte(`{"error": "write failed: hinted handoff queue not empty"}`))
+				_, err = w.Write([]byte(`{"error": "write failed: hinted handoff queue not empty"}`))
+				require.NoError(t, err)
 			},
 			errFunc: func(t *testing.T, err error) {
 				require.NoError(t, err)
@@ -408,7 +417,8 @@ func TestHTTP_Write(t *testing.T) {
 			},
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusBadRequest)
-				w.Write([]byte(`{"error": "partial write: field type conflict:"}`))
+				_, err = w.Write([]byte(`{"error": "partial write: field type conflict:"}`))
+				require.NoError(t, err)
 			},
 			logFunc: func(t *testing.T, str string) {
 				require.Contains(t, str, "partial write")
@@ -423,7 +433,8 @@ func TestHTTP_Write(t *testing.T) {
 			},
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusBadRequest)
-				w.Write([]byte(`{"error": "unable to parse 'cpu value': invalid field format"}`))
+				_, err = w.Write([]byte(`{"error": "unable to parse 'cpu value': invalid field format"}`))
+				require.NoError(t, err)
 			},
 			logFunc: func(t *testing.T, str string) {
 				require.Contains(t, str, "unable to parse")
@@ -456,7 +467,8 @@ func TestHTTP_Write(t *testing.T) {
 			},
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusServiceUnavailable)
-				w.Write([]byte(`{"error": "unknown error"}`))
+				_, err = w.Write([]byte(`{"error": "unknown error"}`))
+				require.NoError(t, err)
 			},
 			errFunc: func(t *testing.T, err error) {
 				expected := &influxdb.APIError{
@@ -549,15 +561,15 @@ func TestHTTP_WritePathPrefix(t *testing.T) {
 	)
 	metrics := []telegraf.Metric{m}
 
-	config := influxdb.HTTPConfig{
+	cfg := influxdb.HTTPConfig{
 		URL:      u,
 		Database: "telegraf",
 		Log:      testutil.Logger{},
 	}
 
-	client, err := influxdb.NewHTTPClient(config)
+	client, err := influxdb.NewHTTPClient(cfg)
 	require.NoError(t, err)
-	err = client.CreateDatabase(ctx, config.Database)
+	err = client.CreateDatabase(ctx, cfg.Database)
 	require.NoError(t, err)
 	err = client.Write(ctx, metrics)
 	require.NoError(t, err)
@@ -603,14 +615,14 @@ func TestHTTP_WriteContentEncodingGzip(t *testing.T) {
 	require.NoError(t, err)
 	metrics := []telegraf.Metric{m}
 
-	config := influxdb.HTTPConfig{
+	cfg := influxdb.HTTPConfig{
 		URL:             u,
 		Database:        "telegraf",
 		ContentEncoding: "gzip",
 		Log:             testutil.Logger{},
 	}
 
-	client, err := influxdb.NewHTTPClient(config)
+	client, err := influxdb.NewHTTPClient(cfg)
 	require.NoError(t, err)
 	err = client.Write(ctx, metrics)
 	require.NoError(t, err)
@@ -648,11 +660,13 @@ func TestHTTP_UnixSocket(t *testing.T) {
 			queryHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				require.Equal(t, `CREATE DATABASE "xyzzy"`, r.FormValue("q"))
 				w.WriteHeader(http.StatusOK)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 			writeHandlerFunc: func(t *testing.T, w http.ResponseWriter, r *http.Request) {
 				w.WriteHeader(http.StatusNoContent)
-				w.Write(successResponse)
+				_, err = w.Write(successResponse)
+				require.NoError(t, err)
 			},
 		},
 	}
@@ -692,7 +706,8 @@ func TestHTTP_WriteDatabaseTagWorksOnRetry(t *testing.T) {
 		http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 			switch r.URL.Path {
 			case "/write":
-				r.ParseForm()
+				err := r.ParseForm()
+				require.NoError(t, err)
 				require.Equal(t, r.Form["db"], []string{"foo"})
 
 				body, err := io.ReadAll(r.Body)
@@ -714,7 +729,7 @@ func TestHTTP_WriteDatabaseTagWorksOnRetry(t *testing.T) {
 		Host:   ts.Listener.Addr().String(),
 	}
 
-	config := influxdb.HTTPConfig{
+	cfg := influxdb.HTTPConfig{
 		URL:                addr,
 		Database:           "telegraf",
 		DatabaseTag:        "database",
@@ -722,7 +737,7 @@ func TestHTTP_WriteDatabaseTagWorksOnRetry(t *testing.T) {
 		Log:                testutil.Logger{},
 	}
 
-	client, err := influxdb.NewHTTPClient(config)
+	client, err := influxdb.NewHTTPClient(cfg)
 	require.NoError(t, err)
 
 	metrics := []telegraf.Metric{
@@ -1008,7 +1023,8 @@ func TestDBRPTagsCreateDatabaseNotCalledOnRetryAfterForbidden(t *testing.T) {
 						return
 					}
 					w.WriteHeader(http.StatusForbidden)
-					w.Write([]byte(`{"results": [{"error": "error authorizing query"}]}`))
+					_, err = w.Write([]byte(`{"results": [{"error": "error authorizing query"}]}`))
+					require.NoError(t, err)
 				default:
 					w.WriteHeader(http.StatusInternalServerError)
 				}
@@ -1080,7 +1096,8 @@ func TestDBRPTagsCreateDatabaseCalledOnDatabaseNotFound(t *testing.T) {
 						return
 					}
 					w.WriteHeader(http.StatusForbidden)
-					w.Write([]byte(`{"results": [{"error": "error authorizing query"}]}`))
+					_, err = w.Write([]byte(`{"results": [{"error": "error authorizing query"}]}`))
+					require.NoError(t, err)
 				default:
 					w.WriteHeader(http.StatusInternalServerError)
 				}
@@ -1089,7 +1106,8 @@ func TestDBRPTagsCreateDatabaseCalledOnDatabaseNotFound(t *testing.T) {
 				switch r.URL.Path {
 				case "/write":
 					w.WriteHeader(http.StatusNotFound)
-					w.Write([]byte(`{"error": "database not found: \"telegraf\""}`))
+					_, err = w.Write([]byte(`{"error": "database not found: \"telegraf\""}`))
+					require.NoError(t, err)
 				default:
 					w.WriteHeader(http.StatusInternalServerError)
 				}
@@ -1197,10 +1215,10 @@ func TestDBNotFoundShouldDropMetricWhenSkipDatabaseCreateIsTrue(t *testing.T) {
 	err = output.Connect()
 	require.NoError(t, err)
 	err = output.Write(metrics)
-	require.Contains(t, logger.LastError, "database not found")
+	require.Contains(t, logger.LastError(), "database not found")
 	require.NoError(t, err)
 
 	err = output.Write(metrics)
-	require.Contains(t, logger.LastError, "database not found")
+	require.Contains(t, logger.LastError(), "database not found")
 	require.NoError(t, err)
 }
