@@ -5,8 +5,8 @@ import (
 	"bytes"
 	"compress/gzip"
 	"fmt"
+	"github.com/influxdata/telegraf/testutil"
 	"io"
-	"io/ioutil"
 	"net/http"
 	"net/http/httptest"
 	"net/url"
@@ -14,7 +14,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
 
 	"github.com/influxdata/telegraf"
@@ -26,7 +25,7 @@ import (
 	"github.com/influxdata/telegraf/plugins/serializers/prometheus"
 )
 
-func getMetric(t *testing.T) telegraf.Metric {
+func getMetric() telegraf.Metric {
 	m := metric.New(
 		"cpu",
 		map[string]string{},
@@ -38,7 +37,7 @@ func getMetric(t *testing.T) telegraf.Metric {
 	return m
 }
 
-func getMetrics(t *testing.T) []telegraf.Metric {
+func getMetrics() []telegraf.Metric {
 	const count = 100
 	var metrics = make([]telegraf.Metric, count)
 
@@ -106,7 +105,7 @@ func TestMethod(t *testing.T) {
 			}
 			require.NoError(t, err)
 
-			err = plugin.Write([]telegraf.Metric{getMetric(t)})
+			err = plugin.Write([]telegraf.Metric{getMetric()})
 			require.NoError(t, err)
 		})
 	}
@@ -178,7 +177,7 @@ func TestStatusCode(t *testing.T) {
 			err = tt.plugin.Connect()
 			require.NoError(t, err)
 
-			err = tt.plugin.Write([]telegraf.Metric{getMetric(t)})
+			err = tt.plugin.Write([]telegraf.Metric{getMetric()})
 			tt.errFunc(t, err)
 		})
 	}
@@ -248,7 +247,8 @@ func TestContentType(t *testing.T) {
 			ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 				gz, err := gzip.NewReader(r.Body)
 				require.NoError(t, err)
-				io.Copy(&body, gz)
+				_, err = io.Copy(&body, gz)
+				require.NoError(t, err)
 				w.WriteHeader(http.StatusOK)
 			}))
 			defer ts.Close()
@@ -261,7 +261,7 @@ func TestContentType(t *testing.T) {
 
 			require.NoError(t, plugin.Connect())
 
-			err = plugin.Write([]telegraf.Metric{getMetric(t)})
+			err = plugin.Write([]telegraf.Metric{getMetric()})
 			require.NoError(t, err)
 
 			if tt.expectedBody != nil {
@@ -300,10 +300,10 @@ func TestContentEncodingGzip(t *testing.T) {
 				body, err := gzip.NewReader(r.Body)
 				require.NoError(t, err)
 
-				payload, err := ioutil.ReadAll(body)
+				payload, err := io.ReadAll(body)
 				require.NoError(t, err)
 
-				assert.Equal(t, string(payload), "metric=cpu field=value  42 0\n")
+				require.Equal(t, string(payload), "metric=cpu field=value  42 0\n")
 
 				w.WriteHeader(http.StatusNoContent)
 			})
@@ -317,14 +317,12 @@ func TestContentEncodingGzip(t *testing.T) {
 			err = plugin.Connect()
 			require.NoError(t, err)
 
-			err = plugin.Write([]telegraf.Metric{getMetric(t)})
+			err = plugin.Write([]telegraf.Metric{getMetric()})
 			require.NoError(t, err)
 		})
 	}
 }
 
-type TestHandlerFunc func(t *testing.T, w http.ResponseWriter, r *http.Request)
-
 func TestDefaultUserAgent(t *testing.T) {
 	ts := httptest.NewServer(http.NotFoundHandler())
 	defer ts.Close()
@@ -350,7 +348,7 @@ func TestDefaultUserAgent(t *testing.T) {
 		err = plugin.Connect()
 		require.NoError(t, err)
 
-		err = plugin.Write([]telegraf.Metric{getMetric(t)})
+		err = plugin.Write([]telegraf.Metric{getMetric()})
 		require.NoError(t, err)
 	})
 }
@@ -395,7 +393,7 @@ func TestTOMLConfig(t *testing.T) {
   url = "https://localhost:3000"
   data_format = "carbon2"
   [outputs.sumologic.headers]
-    X-Sumo-Name = "dummy"       
+    X-Sumo-Name = "dummy"
     X-Sumo-Host = "dummy"
     X-Sumo-Category  = "dummy"
     X-Sumo-Dimensions = "dummy"
@@ -464,7 +462,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.URL = u.String()
 				return s
 			},
-			metrics:                  []telegraf.Metric{getMetric(t)},
+			metrics:                  []telegraf.Metric{getMetric()},
 			expectedError:            false,
 			expectedRequestCount:     1,
 			expectedMetricLinesCount: 1,
@@ -476,7 +474,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.URL = u.String()
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     1,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -491,7 +489,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 43_749
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     2,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -504,7 +502,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 10_000
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     5,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -517,7 +515,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 5_000
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     10,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -530,7 +528,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 2_500
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     20,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -543,7 +541,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 1_000
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     50,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -556,7 +554,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 500
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     100,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -569,7 +567,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 				s.MaxRequstBodySize = 300
 				return s
 			},
-			metrics:                  getMetrics(t),
+			metrics:                  getMetrics(),
 			expectedError:            false,
 			expectedRequestCount:     100,
 			expectedMetricLinesCount: 500, // count (100) metrics, 5 lines per each (steal, idle, system, user, temp) = 500
@@ -597,6 +595,7 @@ func TestMaxRequestBodySize(t *testing.T) {
 
 			plugin := tt.plugin()
 			plugin.SetSerializer(serializer)
+			plugin.Log = testutil.Logger{}
 
 			err = plugin.Connect()
 			require.NoError(t, err)
