@@ -8,8 +8,13 @@ import (
 	"testing"
 	"time"
 
+	"github.com/google/go-cmp/cmp"
 	"github.com/influxdata/telegraf"
+	"github.com/influxdata/telegraf/config"
+	"github.com/influxdata/telegraf/plugins/inputs"
+	"github.com/influxdata/telegraf/plugins/inputs/file"
 	"github.com/influxdata/telegraf/plugins/parsers/influx"
+	"github.com/influxdata/telegraf/plugins/parsers/temporary/xpath"
 	"github.com/influxdata/telegraf/testutil"
 	"github.com/influxdata/toml"
 
@@ -106,14 +111,14 @@ func TestParseInvalidXML(t *testing.T) {
 	var tests = []struct {
 		name          string
 		input         string
-		configs       []Config
+		configs       []xpath.Config
 		defaultTags   map[string]string
 		expectedError string
 	}{
 		{
 			name:  "invalid XML (missing close tag)",
 			input: invalidXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					MetricQuery: "test",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -145,14 +150,14 @@ func TestInvalidTypeQueriesFail(t *testing.T) {
 	var tests = []struct {
 		name          string
 		input         string
-		configs       []Config
+		configs       []xpath.Config
 		defaultTags   map[string]string
 		expectedError string
 	}{
 		{
 			name:  "invalid field (int) type",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					FieldsInt: map[string]string{
@@ -186,14 +191,14 @@ func TestInvalidTypeQueries(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "invalid field type (number)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -214,7 +219,7 @@ func TestInvalidTypeQueries(t *testing.T) {
 		{
 			name:  "invalid field type (boolean)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -256,14 +261,14 @@ func TestParseTimestamps(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse timestamp (no fmt)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 				},
@@ -279,7 +284,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix",
 					TimestampFmt: "unix",
@@ -296,7 +301,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_ms)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_ms",
 					TimestampFmt: "unix_ms",
@@ -313,7 +318,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_us)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_us",
 					TimestampFmt: "unix_us",
@@ -330,7 +335,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (unix_us)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_unix_ns",
 					TimestampFmt: "unix_ns",
@@ -347,7 +352,7 @@ func TestParseTimestamps(t *testing.T) {
 		{
 			name:  "parse timestamp (RFC3339)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_iso",
 					TimestampFmt: "2006-01-02T15:04:05Z",
@@ -385,14 +390,14 @@ func TestParseSingleValues(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse scalar values as string fields",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -419,7 +424,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse scalar values as typed fields (w/o int)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -446,7 +451,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse values as typed fields (w/ int)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -475,7 +480,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -498,7 +503,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values (typed)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Fields: map[string]string{
@@ -521,7 +526,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse substring values (typed int)",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					FieldsInt: map[string]string{
@@ -544,7 +549,7 @@ func TestParseSingleValues(t *testing.T) {
 		{
 			name:  "parse tags",
 			input: singleMetricValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix",
 					Tags: map[string]string{
@@ -588,14 +593,14 @@ func TestParseSingleAttributes(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse attr timestamp (unix)",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 				},
@@ -611,7 +616,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr timestamp (RFC3339)",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp:    "/Device_1/Timestamp_iso/@value",
 					TimestampFmt: "2006-01-02T15:04:05Z",
@@ -628,7 +633,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as string fields",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -655,7 +660,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as typed fields (w/o int)",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -682,7 +687,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr as typed fields (w/ int)",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -711,7 +716,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr substring",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -732,7 +737,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr tags",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Tags: map[string]string{
@@ -755,7 +760,7 @@ func TestParseSingleAttributes(t *testing.T) {
 		{
 			name:  "parse attr bool",
 			input: singleMetricAttributesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Device_1/Timestamp_unix/@value",
 					Fields: map[string]string{
@@ -797,14 +802,14 @@ func TestParseMultiValues(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "select values (float)",
 			input: singleMetricMultiValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Timestamp/@value",
 					Fields: map[string]string{
@@ -835,7 +840,7 @@ func TestParseMultiValues(t *testing.T) {
 		{
 			name:  "select values (int)",
 			input: singleMetricMultiValuesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Timestamp: "/Timestamp/@value",
 					FieldsInt: map[string]string{
@@ -887,14 +892,14 @@ func TestParseMultiNodes(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    []telegraf.Metric
 	}{
 		{
 			name:  "select all devices",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device",
 					Timestamp: "/Timestamp/@value",
@@ -1004,14 +1009,14 @@ func TestParseMetricQuery(t *testing.T) {
 	var tests = []struct {
 		name        string
 		input       string
-		configs     []Config
+		configs     []xpath.Config
 		defaultTags map[string]string
 		expected    telegraf.Metric
 	}{
 		{
 			name:  "parse metric name query",
 			input: metricNameQueryXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					MetricQuery: "name(/Device_1/Metric/@*[1])",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1033,7 +1038,7 @@ func TestParseMetricQuery(t *testing.T) {
 		{
 			name:  "parse metric name constant",
 			input: metricNameQueryXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					MetricQuery: "'the_metric'",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1076,13 +1081,13 @@ func TestParseErrors(t *testing.T) {
 	var tests = []struct {
 		name     string
 		input    string
-		configs  []Config
+		configs  []xpath.Config
 		expected string
 	}{
 		{
 			name:  "string metric name query",
 			input: metricNameQueryXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					MetricQuery: "arbitrary",
 					Timestamp:   "/Device_1/Timestamp_unix",
@@ -1116,12 +1121,12 @@ func TestEmptySelection(t *testing.T) {
 	var tests = []struct {
 		name    string
 		input   string
-		configs []Config
+		configs []xpath.Config
 	}{
 		{
 			name:  "empty path",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device/NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1133,7 +1138,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty pattern",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "//NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1145,7 +1150,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty axis",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device/child::NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1157,7 +1162,7 @@ func TestEmptySelection(t *testing.T) {
 		{
 			name:  "empty predicate",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device[@NonExisting=true]",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1189,12 +1194,12 @@ func TestEmptySelectionAllowed(t *testing.T) {
 	var tests = []struct {
 		name    string
 		input   string
-		configs []Config
+		configs []xpath.Config
 	}{
 		{
 			name:  "empty path",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device/NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1206,7 +1211,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty pattern",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "//NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1218,7 +1223,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty axis",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device/child::NonExisting",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1230,7 +1235,7 @@ func TestEmptySelectionAllowed(t *testing.T) {
 		{
 			name:  "empty predicate",
 			input: multipleNodesXML,
-			configs: []Config{
+			configs: []xpath.Config{
 				{
 					Selection: "/Device[@NonExisting=true]",
 					Fields:    map[string]string{"value": "number(Value)"},
@@ -1301,7 +1306,8 @@ func TestTestCases(t *testing.T) {
 		},
 	}
 
-	parser := influx.NewParser(influx.NewMetricHandler())
+	parser := &influx.Parser{}
+	require.NoError(t, parser.Init())
 
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
@@ -1354,7 +1360,7 @@ func TestTestCases(t *testing.T) {
 				Format:              fileformat,
 				ProtobufMessageDef:  pbmsgdef,
 				ProtobufMessageType: pbmsgtype,
-				Configs:             []Config{*cfg},
+				Configs:             []xpath.Config{*cfg},
 				Log:                 testutil.Logger{Name: "parsers.xml"},
 			}
 			require.NoError(t, parser.Init())
@@ -1380,13 +1386,97 @@ func TestProtobufImporting(t *testing.T) {
 		ProtobufMessageDef:  "person.proto",
 		ProtobufMessageType: "importtest.Person",
 		ProtobufImportPaths: []string{"testcases/protos"},
-		Configs:             []Config{},
+		Configs:             []xpath.Config{},
 		Log:                 testutil.Logger{Name: "parsers.protobuf"},
 	}
 	require.NoError(t, parser.Init())
 }
 
-func loadTestConfiguration(filename string) (*Config, []string, error) {
+func TestMultipleConfigs(t *testing.T) {
+	// Get all directories in testdata
+	folders, err := os.ReadDir("testcases")
+	require.NoError(t, err)
+
+	// Make sure the folder contains data
+	require.NotEmpty(t, folders)
+
+	// Register the wrapper plugin
+	inputs.Add("file", func() telegraf.Input {
+		return &file.File{}
+	})
+
+	// Prepare the influx parser for expectations
+	parser := &influx.Parser{}
+	require.NoError(t, parser.Init())
+
+	// Compare options
+	options := []cmp.Option{
+		testutil.IgnoreTime(),
+		testutil.SortMetrics(),
+	}
+
+	for _, f := range folders {
+		// Only handle folders
+		if !f.IsDir() || f.Name() == "protos" {
+			continue
+		}
+		testcasePath := filepath.Join("testcases", f.Name())
+		configFilename := filepath.Join(testcasePath, "telegraf.conf")
+		expectedFilename := filepath.Join(testcasePath, "expected.out")
+		expectedErrorFilename := filepath.Join(testcasePath, "expected.err")
+
+		t.Run(f.Name(), func(t *testing.T) {
+			// Read the expected output if any
+			var expected []telegraf.Metric
+			if _, err := os.Stat(expectedFilename); err == nil {
+				var err error
+				expected, err = testutil.ParseMetricsFromFile(expectedFilename, parser)
+				require.NoError(t, err)
+			}
+
+			// Read the expected output if any
+			var expectedErrors []string
+			if _, err := os.Stat(expectedErrorFilename); err == nil {
+				var err error
+				expectedErrors, err = testutil.ParseLinesFromFile(expectedErrorFilename)
+				require.NoError(t, err)
+				require.NotEmpty(t, expectedErrors)
+			}
+
+			// Configure the plugin
+			cfg := config.NewConfig()
+			require.NoError(t, cfg.LoadConfig(configFilename))
+			require.NotEmpty(t, cfg.Inputs)
+
+			// Gather the metrics from the input file configure
+			var acc testutil.Accumulator
+			var errs []error
+			for _, input := range cfg.Inputs {
+				require.NoError(t, input.Init())
+				err := input.Gather(&acc)
+				if err != nil {
+					errs = append(errs, err)
+				}
+			}
+
+			// Check for errors if we expect any
+			if len(expectedErrors) > 0 {
+				require.Len(t, errs, len(expectedErrors))
+				for i, err := range errs {
+					require.ErrorContains(t, err, expectedErrors[i])
+				}
+			} else {
+				require.Empty(t, errs)
+			}
+
+			// Process expected metrics and compare with resulting metrics
+			actual := acc.GetTelegrafMetrics()
+			testutil.RequireMetricsEqual(t, expected, actual, options...)
+		})
+	}
+}
+
+func loadTestConfiguration(filename string) (*xpath.Config, []string, error) {
 	buf, err := os.ReadFile(filename)
 	if err != nil {
 		return nil, nil, err
@@ -1399,7 +1489,7 @@ func loadTestConfiguration(filename string) (*Config, []string, error) {
 			header = append(header, line)
 		}
 	}
-	cfg := Config{}
+	cfg := xpath.Config{}
 	err = toml.Unmarshal(buf, &cfg)
 	return &cfg, header, err
 }
