@@ -5,20 +5,17 @@ import (
 	_ "embed"
 
 	"github.com/influxdata/telegraf"
-	"github.com/influxdata/telegraf/models"
-	"github.com/influxdata/telegraf/plugins/parsers"
 	"github.com/influxdata/telegraf/plugins/processors"
 )
 
-// DO NOT REMOVE THE NEXT TWO LINES! This is required to embed the sampleConfig data.
 //go:embed sample.conf
 var sampleConfig string
 
 type Parser struct {
-	parsers.Config
 	DropOriginal bool            `toml:"drop_original"`
 	Merge        string          `toml:"merge"`
 	ParseFields  []string        `toml:"parse_fields"`
+	ParseTags    []string        `toml:"parse_tags"`
 	Log          telegraf.Logger `toml:"-"`
 	parser       telegraf.Parser
 }
@@ -27,37 +24,37 @@ func (*Parser) SampleConfig() string {
 	return sampleConfig
 }
 
+func (p *Parser) SetParser(parser telegraf.Parser) {
+	p.parser = parser
+}
+
 func (p *Parser) Apply(metrics ...telegraf.Metric) []telegraf.Metric {
-	if p.parser == nil {
-		var err error
-		p.parser, err = parsers.NewParser(&p.Config)
-		if err != nil {
-			p.Log.Errorf("could not create parser: %v", err)
-			return metrics
-		}
-		models.SetLoggerOnPlugin(p.parser, p.Log)
-	}
-
 	results := []telegraf.Metric{}
-
 	for _, metric := range metrics {
 		newMetrics := []telegraf.Metric{}
 		if !p.DropOriginal {
 			newMetrics = append(newMetrics, metric)
 		}
 
+		// parse fields
 		for _, key := range p.ParseFields {
 			for _, field := range metric.FieldList() {
 				if field.Key == key {
 					switch value := field.Value.(type) {
 					case string:
-						fromFieldMetric, err := p.parseField(value)
+						fromFieldMetric, err := p.parseValue(value)
 						if err != nil {
 							p.Log.Errorf("could not parse field %s: %v", key, err)
 						}
 
 						for _, m := range fromFieldMetric {
-							if m.Name() == "" {
+							// The parser get the parent plugin's name as
+							// default measurement name. Thus, in case the
+							// parsed metric does not provide a name itself,
+							// the parser  will return 'parser' as we are in
+							// processors.parser. In those cases we want to
+							// keep the original metric name.
+							if m.Name() == "" || m.Name() == "parser" {
 								m.SetName(metric.Name())
 							}
 						}
@@ -73,6 +70,30 @@ func (p *Parser) Apply(metrics ...telegraf.Metric) []telegraf.Metric {
 			}
 		}
 
+		// parse tags
+		for _, key := range p.ParseTags {
+			if value, ok := metric.GetTag(key); ok {
+				fromTagMetric, err := p.parseValue(value)
+				if err != nil {
+					p.Log.Errorf("could not parse tag %s: %v", key, err)
+				}
+
+				for _, m := range fromTagMetric {
+					// The parser get the parent plugin's name as
+					// default measurement name. Thus, in case the
+					// parsed metric does not provide a name itself,
+					// the parser  will return 'parser' as we are in
+					// processors.parser. In those cases we want to
+					// keep the original metric name.
+					if m.Name() == "" || m.Name() == "parser" {
+						m.SetName(metric.Name())
+					}
+				}
+
+				newMetrics = append(newMetrics, fromTagMetric...)
+			}
+		}
+
 		if len(newMetrics) == 0 {
 			continue
 		}
@@ -99,7 +120,7 @@ func merge(base telegraf.Metric, metrics []telegraf.Metric) telegraf.Metric {
 	return base
 }
 
-func (p *Parser) parseField(value string) ([]telegraf.Metric, error) {
+func (p *Parser) parseValue(value string) ([]telegraf.Metric, error) {
 	return p.parser.Parse([]byte(value))
 }
 
